@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2016, 2021, Oracle and/or its affiliates.
+ * Copyright (c) 2016, 2022, Oracle and/or its affiliates.
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License, version 2.0,
@@ -107,8 +107,7 @@ class Cluster_impl : public Base_cluster_impl,
                        bool interactive, bool skip_precondition_check);
 
   void remove_instance(const Connection_options &instance_def,
-                       const mysqlshdk::null_bool &force,
-                       const bool interactive);
+                       const cluster::Remove_instance_options &options);
   shcore::Value describe();
   shcore::Value options(const bool all);
   shcore::Value status(int64_t extended);
@@ -119,7 +118,9 @@ class Cluster_impl : public Base_cluster_impl,
   void rescan(const cluster::Rescan_options &options);
   void switch_to_single_primary_mode(const Connection_options &instance_def);
   void switch_to_multi_primary_mode();
-  void set_primary_instance(const Connection_options &instance_def);
+  void set_primary_instance(
+      const Connection_options &instance_def,
+      const cluster::Set_primary_instance_options &options);
   shcore::Value check_instance_state(const Connection_options &instance_def);
   void reset_recovery_password(const mysqlshdk::null_bool &force,
                                const bool interactive);
@@ -150,10 +151,12 @@ class Cluster_impl : public Base_cluster_impl,
       const mysqlshdk::db::Connection_options &instance_def);
 
   void update_metadata_for_instance(
-      const mysqlshdk::db::Connection_options &instance_definition) const;
+      const mysqlshdk::db::Connection_options &instance_definition,
+      Instance_id instance_id = 0, const std::string &label = "") const;
 
-  void update_metadata_for_instance(
-      const mysqlshdk::mysql::IInstance &instance) const;
+  void update_metadata_for_instance(const mysqlshdk::mysql::IInstance &instance,
+                                    Instance_id instance_id = 0,
+                                    const std::string &label = "") const;
 
   bool get_disable_clone_option() const;
   void set_disable_clone_option(const bool disable_clone);
@@ -183,9 +186,11 @@ class Cluster_impl : public Base_cluster_impl,
   std::pair<mysqlshdk::mysql::Auth_options, std::string>
   create_replication_user(mysqlshdk::mysql::IInstance *target);
 
-  void drop_replication_user_old(mysqlshdk::mysql::IInstance *target);
-  bool drop_replication_user(const std::string &server_uuid,
-                             const std::string &endpoint);
+  bool drop_replication_user(mysqlshdk::mysql::IInstance *target,
+                             const std::string &endpoint = "",
+                             const std::string &server_uuid = "",
+                             const uint32_t server_id = 0);
+
   void drop_replication_users();
 
   bool contains_instance_with_address(const std::string &host_port) const;
@@ -351,18 +356,6 @@ class Cluster_impl : public Base_cluster_impl,
   void ensure_metadata_has_server_id(
       const mysqlshdk::mysql::IInstance &target_instance);
 
-  /**
-   * Ensures group_replication_view_change_uuid is set on all Cluster members
-   * and stored in the Metadata schema.
-   *
-   * Only effective when the Cluster members are running MySQL >= 8.0.27
-   *
-   * @param target_instance The instance to be used to get the cluster members
-   * to update the group_replication_view_change_uuid option.
-   */
-  void ensure_view_change_uuid_set(
-      const mysqlshdk::mysql::IInstance &target_instance);
-
   /**
    * Checks for missing metadata recovery account entries, and fix them using
    * info from mysql.slave_master_info.
